pub struct SsoCookieVendorConfig {
pub idp_login_url: Option<String>,
pub cookie_name: Option<String>,
pub cookie_domain: Option<String>,
pub cookie_value: Option<Vec<AcquiredCookie>>,
}Expand description
SSO cookie vendor configuration
This configuration is provided by the server.
Fields
idp_login_url: Option<String>Identity provider login URL for browser redirect during bootstrap
Cookie name (base name, without shard suffix)
Cookie domain for validation
Acquired cookies
For sharded cookies, this contains multiple entries with names like
AWSELBAuthSessionCookie-0, AWSELBAuthSessionCookie-1, etc.
For unsharded cookies, this contains a single entry with the base name.